@@ -4,17 +4,15 @@
 #' @param branch git branch
 #' @param git_args arguments to git
 #' @param git_binary location of git executable
-#' @return git commit output
+#' @return Not for direct use. Git commit output.
 #' @export
 #' @examples 
 #'\dontrun{
-#'  si <- pull_source_info("adaprHome")
-#' git.commit(si$project.path,"test commit")
+#'  si <- pullSourceInfo("adaprHome")
+#' gitCommit(si$project.path,"test commit")
 #'} 
 #' 
-
-
-git.commit <- function(gitdir,message,branch = NULL, git_args = character(), git_binary = NULL){
+gitCommit <- function(gitdir,message,branch = NULL, git_args = character(), git_binary = NULL){
   
   # git "commit" to the git repository in gitdir with message 
   
@@ -32,4 +30,3 @@ git.commit <- function(gitdir,message,branch = NULL, git_args = character(), git
   return(git.out)
   
 }
-
