@@ -7,10 +7,9 @@
 #' @export
 #' @examples 
 #'\dontrun{
-#'  git.init(get.project.path("adaprHome"))
+#'  gitInit(getProjectPath("adaprHome"))
 #'} 
-
-git.init <- function(gitdir,branch = NULL, git_binary = NULL){
+gitInit <- function(gitdir,branch = NULL, git_binary = NULL){
   
   # extract the git information related to a filename in the git repository in gitdir
   
@@ -25,4 +24,4 @@ git.init <- function(gitdir,branch = NULL, git_binary = NULL){
   
   return(git.out)
   
-}
\ No newline at end of file
+}
