@@ -6,23 +6,22 @@
 #' @export
 #'@examples 
 #'\dontrun{
-#'  projpath <- file.path(get.project.path("adaprHome"),"Programs")
-#'  git_provenance("adaprHome",file.path(projpath,"read_data.R"))
+#'  projpath <- file.path(getProjectPath("adaprHome"),"Programs")
+#'  gitProvenance("adaprHome",file.path(projpath,"read_data.R"))
 #'} 
 #' 
-git_provenance <- function(project.id,filepath=0){
-
+gitProvenance <- function(project.id,filepath=0){
   if(filepath==0){filepath <- file.choose()}
   
   filehash <- Digest(file=filepath)
   
-  gitpath <- get.project.path(project.id)
+  gitpath <- getProjectPath(project.id)
   
-  provenance <- git.history.search(gitpath,filehash)  
+  provenance <- gitHistorySearch(gitpath,filehash)  
   
-  si <- pull_source_info(project.id)
+  si <- pullSourceInfo(project.id)
   
-  files <- Condense.file.info(Harvest.trees(si$dependency.dir))
+  files <- condenseFileInfo(readDependency(si$dependency.dir))
                               
   file.data <- subset(files,files$file.hash==filehash)   
   
@@ -32,5 +31,3 @@ git_provenance <- function(project.id,filepath=0){
   
   return(list(file=filepath,gitHistory=provenance,currentDescription=file.data))
 }
-
-
