@@ -5,13 +5,11 @@
 #' @export
 #' @examples 
 #'\dontrun{
-#'  path <- get.project.path("adaprHome")
+#'  path <- getProjectPath("adaprHome")
 #'  path <- file.path(path,"Programs",project.directory.tree$support)
-#'  load.source.directory(path)
+#'  runSourceDirectory(path)
 #'} 
-
-load.source.directory <- function(source.directory){
-
+runSourceDirectory <- function(source.directory){
   
   source.file.list <- list.files(source.directory,pattern="(\\.R$)|(\\.r$)",full.names=TRUE,include.dirs=FALSE)
   
