@@ -6,12 +6,14 @@
 #' @export
 #' @examples 
 #'\dontrun{
-#'  make.hyperlink("myPath","click here to my path")
+#'  makeHyperlink("myPath","click here to my path")
 #'}
-make.hyperlink <- function(files,links){
+makeHyperlink <- function(files,links){
   
   link.command <- rep("",length(files))
   
+  if(length(files)==0){stop("Error makeHyperlink: no files to link")}
+  
   for(file.iter in 1:length(files)){
     link.command[file.iter] <- paste0("<a href=\"file:///",files[file.iter],"\">",links[file.iter],"</a>")
     
@@ -20,4 +22,4 @@ make.hyperlink <- function(files,links){
   }
   return(link.command)
   
-}
\ No newline at end of file
+}
