@@ -9,9 +9,9 @@ scriptLoader <- function(projectID,script){
   # initialize dependency file R object, store filename
   # project.path is for git
   
-  programPath <- file.path(get.project.path(projectID),project.directory.tree$analysis,script)
+  programPath <- file.path(getProjectPath(projectID),project.directory.tree$analysis,script)
   
-  resultsPath <- file.path(get.project.path(projectID),project.directory.tree$results,script)
+  resultsPath <- file.path(getProjectPath(projectID),project.directory.tree$results,script)
   
   setwd(resultsPath)
   
@@ -30,7 +30,6 @@ scriptLoader <- function(projectID,script){
   return(1)
   
 }	
-
 #' Checks whether interactive R markdown session is ON
 #' @param changeOption logical to print out and change the Rmdstart option
 #' @return value TRUE if R session in in interactive R markdown mode
@@ -56,5 +55,3 @@ checkRmdMode <- function(changeOption=FALSE){
   
   
 }
-
-
