@@ -1,24 +1,24 @@
-#' Synchronize project by running necessary R scripts
+#' Lower level function that synchronizes project by running necessary R scripts. Loads from source_info list.
 #' @param source_info Project information within source_info list
 #' @param run logical indicated whether to run or just identify asynchrony
 #' @param plot.to.file logical for writing file in tree_controller.R directory
 #' @return Data.frame with sources needed to synchronize with run times
 #' @export
-#' @details Not usually direct use. See sync.project() and synctest.project().
+#' @details Not usually direct use. See syncProject() and syncTestProject().
 #' @examples 
 #'\dontrun{
 #' source_info <- create_source_file_dir("adaprHome","tree_controller.R")
-#' source.sync.si(source_info)
+#' sourceSyncSI(source_info)
 #'} 
-source.sync.si <- function(source_info,run=TRUE,plot.to.file=FALSE){
+sourceSyncSI <- function(source_info,run=TRUE,plot.to.file=FALSE){
   
   # Run in order 
   # Compute run times
   
   
-  project_info <- get.project.info.si(source_info)
+  project_info <- getProjectInfoSI(source_info)
   
-  sync.out <- Sync.test.pi(project_info)
+  sync.out <- syncTestPI(project_info)
   
   if(sync.out$synchronized){
     
@@ -27,16 +27,16 @@ source.sync.si <- function(source_info,run=TRUE,plot.to.file=FALSE){
     return(NULL)}
   
   
-  ID.sync.out <- sync.out$sources.to.sync
+  idSync.out <- sync.out$sources.to.sync
   
-  if(nrow(ID.sync.out)==0){
+  if(nrow(idSync.out)==0){
     warning("There is nothing to run")
   }
   
-  tree.to.run <- subset(project_info$tree,project_info$tree$source.file %in% ID.sync.out$file)	
+  tree.to.run <- subset(project_info$tree,project_info$tree$source.file %in% idSync.out$file)	
   
   
-  sync.out <- sync.test.si(source_info)
+  sync.out <- syncTestSI(source_info)
   
   propagated.names <- igraph::V(sync.out$propagated.graph)$name[igraph::V(sync.out$propagated.graph)$synced=="No"]
   
@@ -49,7 +49,7 @@ source.sync.si <- function(source_info,run=TRUE,plot.to.file=FALSE){
   
   #Plot.biggraph.horizontal(project_info$graph,title="Files to syncrhonise",black.vertex.list=propagated.names)			
   
-  create_program_graph(source_info$project.id)
+  createProgramGraph(source_info$project.id)
   
   if(plot.to.file){grDevices::graphics.off()}
   
@@ -68,11 +68,14 @@ source.sync.si <- function(source_info,run=TRUE,plot.to.file=FALSE){
   
   print("Starting synchronization")
   
-  if(run){
+  
+
+  
+  if(run&(nrow(idSync.out)>0)){
     
-    for(source.iter in 1:(nrow(ID.sync.out)+1)){
+    for(source.iter in 1:(nrow(idSync.out)+1)){
       
-      sync.out <- sync.test.si(source_info)
+      sync.out <- syncTestSI(source_info)
       
       if(sync.out$synchronized){
         propagated.names <- ""
@@ -82,18 +85,18 @@ source.sync.si <- function(source_info,run=TRUE,plot.to.file=FALSE){
       remaining.time <- paste0(sum(subset(run.times,run.times$source.file %in% sync.out$sources.to.sync$file)$last.run.time.sec,na.rm=TRUE)," secs")
       
       title.of.graph <- paste(ifelse(sync.out$synchronized,"Sychronized Remaining","Files to synchronize"),"Run time = ",remaining.time,
-                      "\n",ID.sync.out$file[source.iter])        
+                      "\n",idSync.out$file[source.iter])        
                               
                       
       
       if(plot.to.file){grDevices::png(syncPlotFile)}
       
       
-      create_program_graph(source_info$project.id)
+      createProgramGraph(source_info$project.id)
       
       if(plot.to.file){grDevices::graphics.off()}
       
-      if(source.iter<=nrow(ID.sync.out)){devtools::clean_source(file.path(ID.sync.out$path[source.iter],ID.sync.out$file[source.iter]))}
+      if(source.iter<=nrow(idSync.out)){devtools::clean_source(file.path(idSync.out$path[source.iter],idSync.out$file[source.iter]))}
       
       
     }
@@ -109,4 +112,4 @@ source.sync.si <- function(source_info,run=TRUE,plot.to.file=FALSE){
   return(run.times)
   
   
-}# source.sync.si
\ No newline at end of file
+}# sourceSyncSI
