@@ -1,11 +1,11 @@
-#' Take list of dependency file data and changes the project path
+#' Lower level function that takes list of dependency file data and changes the project path
 #' @param list.deps list of dependency file data
 #' @param new.path file path for the new project path
-#' @details Not for direct use. Used with swapping branches by rework.project.path()
+#' @details Not for direct use. Used with swapping branches by reworkProjectPath()
 #' @return Updated list of dependency data
 #' @export
 #' 
-swap.project.paths <-   function(list.deps,new.path=get.project.path(get("source_info")$project.id)){
+swapProjectPath <-   function(list.deps,new.path=getProjectPath(get("source_info")$project.id)){
   
   # list.deps = list of dependency output files
   
@@ -15,11 +15,15 @@ swap.project.paths <-   function(list.deps,new.path=get.project.path(get("source
   shaved.variables <- c("path","source.file.path","target.path","project.path")
   
   
+  if(length(list.deps)==0){stop("Error in swapProjectPath no dependencies")}
+  
   for(i in 1:length(list.deps)){
     
     for(char.shave in shaved.variables){
       
-      for(file.iter in 1:nrow(list.deps[[i]])){
+      
+      
+      for(file.iter in seq_along(list.deps[[i]][,1])){
         
         old.project.path <- list.deps[[i]]$project.path[file.iter] 	
         
@@ -36,4 +40,4 @@ swap.project.paths <-   function(list.deps,new.path=get.project.path(get("source
   
   return(list.deps)
   
-}# END: swap.project.paths	
\ No newline at end of file
+}# END: swapProjectPath	
